"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const webpack = require("webpack");
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const SpriteLoaderPlugin = require('svg-sprite-loader/plugin');
const env = process.env.NODE_ENV;
function default_1(params) {
    const { version, outputDir, publicPath, addVersion } = params;
    const plugins = [
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify(env),
                version: JSON.stringify(version),
                outputDir: JSON.stringify(outputDir),
                publicPath: JSON.stringify(publicPath),
            },
        }),
        new webpack.NoEmitOnErrorsPlugin(),
        new SpriteLoaderPlugin(),
        new ExtractTextPlugin({
            filename: addVersion ? `css/[name]_${version}.css` : 'css/[name].css',
            allChunks: true
        }),
    ];
    if (env === 'production') {
        plugins.push(new webpack.optimize.UglifyJsPlugin({
            // 最紧凑的输出
            beautify: false,
            // 删除所有的注释
            comments: false,
            sourceMap: true,
            compress: {
                // 在UglifyJs删除没有用到的代码时不输出警告
                warnings: false,
                // 删除所有的 console 语句
                // 还可以兼容ie浏览器
                drop_console: true,
                // 内嵌定义了但是只用到一次的变量
                collapse_vars: true,
                // 提取出出现多次但是没有定义成变量去引用的静态值
                reduce_vars: true
            }
        }));
        plugins.push(new webpack.optimize.ModuleConcatenationPlugin());
        // plugins.push(new webpack.DllReferencePlugin({
        //   context: __dirname,
        //   manifest: env === 'production' ? manifest : manifestDev
        // }))
    }
    return plugins;
}
exports.default = default_1;
