"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const clean_1 = require("./clean");
const resolve_1 = require("./resolve");
const plugins_1 = require("./plugins");
const fs = require("fs");
const childProcess = require("child_process");
const ExtractTextPlugin = require('extract-text-webpack-plugin');
// Node环境变量是否是development
const isDev = process.env.NODE_ENV === 'development' ? true : false;
// 默认输出目录
const defaultOutputDir = 'build';
// 默认配置参数
const defaultParams = {
    dirname: '',
    outputDir: defaultOutputDir,
    publicPath: '',
};
function default_1(params) {
    const assignParams = Object.assign({}, defaultParams, params);
    const { dirname, isRouter } = assignParams;
    const outputDir = assignParams.outputDir;
    const publicPath = assignParams.publicPath;
    const pkg = JSON.parse(fs.readFileSync(path.resolve(dirname, 'package.json'), { encoding: 'utf8' }));
    const filename = `[name]_${pkg.version}.js`;
    // 清空输出目录
    clean_1.default(path.resolve(dirname, outputDir));
    if (!isRouter) {
        childProcess.exec('ruler transform router', { cwd: dirname });
    }
    return {
        entry: {
            index: path.resolve(dirname, './src/entry/index.tsx')
        },
        output: {
            publicPath,
            path: path.resolve(dirname, outputDir),
            filename: './js/' + filename,
            chunkFilename: 'js/' + filename
        },
        resolve: resolve_1.default(dirname),
        plugins: plugins_1.default({
            version: pkg.version,
            outputDir,
            publicPath
        }),
        devtool: isDev ? 'inline-source-map' : undefined,
        externals: isDev ? {
            'react/addons': true,
            'react/lib/ExecutionEnvironment': true,
            'react/lib/ReactContext': true,
            'react-addons-test-utils': 'react-dom',
        } : undefined,
        module: {
            rules: [{
                    test: /.tsx?$/,
                    loaders: ['ts-loader'],
                    exclude: /node_modules/,
                }, {
                    test: /\.svg$/,
                    loader: 'svg-sprite-loader',
                    options: {
                        extract: true,
                        esModule: false,
                        spriteFilename: `/svg/sprite_${pkg.version}.svg`
                    }
                }, {
                    test: /\.(png|jpg|gif)$/,
                    loader: 'file-loader',
                    options: {
                        name: '[name].[ext]',
                        outputPath: 'img/'
                    }
                }, {
                    test: /\.scss$/,
                    use: ExtractTextPlugin.extract({
                        use: [{
                                loader: 'typings-for-css-modules-loader',
                                options: {
                                    modules: true,
                                    namedExport: true,
                                    camelCase: true,
                                    minimize: !isDev,
                                    localIdentName: '[local]_[hash:base64:5]'
                                }
                            }, {
                                loader: 'postcss-loader',
                                options: {
                                    config: {
                                        path: path.resolve(__dirname, 'postcss.config.js'),
                                    },
                                    sourceMap: isDev
                                }
                            }, {
                                loader: 'sass-loader',
                                options: {
                                    outputStyle: 'expanded',
                                    sourceMap: isDev
                                }
                            }]
                    })
                }]
        }
    };
}
exports.default = default_1;
